@@ -3,7 +3,7 @@
  * Copyright (C) 2014 Red Hat, Inc.
  */
 
-#include "nm-default.h"
+#include "libnm-core/nm-default-libnm-core.h"
 
 #include "nm-setting-ip4-config.h"
 
@@ -946,6 +946,13 @@ nm_setting_ip4_config_class_init(NMSettingIP4ConfigClass *klass)
      *   for that subnet.
      * ---end---
      */
+    /* ---nmcli---
+     * property: addresses
+     * format: a comma separated list of addresses
+     * description: A list of IPv4 addresses and their prefix length. Multiple addresses
+     * can be separated by comma. For example "192.168.1.5/24, 10.1.0.5/24".
+     * ---end---
+     */
     _nm_properties_override_gobj(
         properties_override,
         g_object_class_find_property(G_OBJECT_CLASS(setting_class), NM_SETTING_IP_CONFIG_ADDRESSES),
